@@ -7,7 +7,10 @@
 #'@param rettype character Format in which to get data (eg, fasta, xml...)
 #'@param retmode character Mode in which to recieve data, defaults to 'text'
 #'@param \dots character Additional terms to add to the request
+#'@param config vector configuration options passed to httr::GET
+#'@seealso \code{\link[httr]{config}} for avaliable configs
 #'@return chracter string containing the file created
+#
 #' @examples
 #' 
 #' katipo <- "Latrodectus katipo[Organism]"
@@ -15,10 +18,10 @@
 #' kaitpo_seqs <- entrez_fetch(db="nuccore", id=katipo_search$ids, rettype="fasta")
 #'
 
-entrez_fetch <- function(db, rettype, retmode="text", ...){
-    url_string <- make_entrez_query("efetch", 
-          require_one_of = c("id", "WebEnv"), db=db, ..., rettype=rettype)
-    records <- getURL(url_string)
+entrez_fetch <- function(db, rettype, retmode="text", config=NULL, ...){
+    records <- make_entrez_query("efetch", db=db, rettype=rettype,
+                                 config=config, ..., 
+                                 require_one_of = c("id", "WebEnv"))
     #NCBI limits requests to three per second
     Sys.sleep(0.33)
     return(records)
